@@ -2,7 +2,7 @@ package WikiText::Sample::Parser;
 use base 'WikiText::Parser';
 
 sub create_grammar {
-    my $all_blocks = [ 'h1',  'h2', 'h3', 'hr', 'p' ];
+    my $all_blocks = [ 'h1',  'h2', 'h3', 'hr', 'p', 'pre' ];
 
     my $all_phrases = [ 'b', 'i' ];
 
@@ -15,7 +15,8 @@ sub create_grammar {
             match => qr/^           # Blocks must start at beginning
             (                       # Capture paragraph in $1
                 ((?!(?:             # Stop at certain blocks
-                    [\=]            # Headings
+                    [\=] |          # Headings
+                    \s+\S
                 ))
                 .*\S.*\n)+          # Otherwise, collect non-empty lines
             )
@@ -24,6 +25,18 @@ sub create_grammar {
             phrases => $all_phrases,
             filter => sub { chomp },
         },
+        pre => {
+            match => qr/^
+            (
+                ((?!(?:             # Stop at certain blocks
+                    \S              # Anything starting with nonspace
+                ))
+                (?m: ^\ +.*\S.*\n))+ # otherwise grab lines starting with space
+            )
+            (\s*\n)*   # and all blank lines after
+            /x,
+            filter => sub { s/^\s*//mg; s/\s*$//mg; },
+        },
         h1 => {
             match => re_header(1),
         },
@@ -70,31 +83,3 @@ sub re_header {
 }
 
 1;
-
-=head1 NAME
-
-WikiText::Sample::Parser - A Parser For Sample Markup
-
-=head1 SYNOPSIS
-
-    use WikiText::Sample::Parser;
-    
-=head1 DESCRIPTION
-
-This module turns Sample markup text into parse events end sends them to
-a receiver.
-
-=head1 AUTHOR
-
-Ingy döt Net <ingy@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2008. Ingy döt Net.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See http://www.perl.com/perl/misc/Artistic.html
-
-=cut
