@@ -1,23 +1,46 @@
 package WikiText::namespace;
+
 package WikiText::Creole;
 ;
+
 package WikiText::DokuWiki;
 my $x = 1;
+
 package WikiText::HTML;
 
 package WikiText::Kwiki;
 #
+
 package WikiText::MediaWiki;
+
 package WikiText::MoinMoin;
+
+use strict;
+sub foo {
+    my ($x, $y) = @_;
+    return 42;
+}
+
 package WikiText::OddMuse;
+
 package WikiText::PBWiki;
+
 package WikiText::Pod;
+
 package WikiText::PurpleWiki;
+
 package WikiText::TWiki;
+
 package WikiText::TiddlyWiki;
+
 package WikiText::Trac;
+
 package WikiText::UseMod;
+
 package WikiText::Wifty;
+
 package WikiText::WikiByte;
+
 package WikiText::Wikiwyg;
+
 1;
